@@ -105,6 +105,12 @@ class SecurityValueHolder(object):
             self.updated = True
             return SecuritiesValues(values, index=keys)
 
+    def value_by_names(self, names):
+        if self.updated:
+            return self.cached[names]
+        else:
+            return SecuritiesValues([self._innerHolders[name].result() for name in names], index=names)
+
     def value_by_name(self, name):
         if self.updated:
             return self.cached[name]
@@ -216,7 +222,7 @@ class SecurityValueHolder(object):
             for j, dict_data in enumerate(split_values):
                 self.push(dict_data)
                 end_count = start_count + len(dict_data)
-                output_values[start_count:end_count, 0] = self.value[split_category[j]]
+                output_values[start_count:end_count, 0] = self.value_by_names(split_category[j])
                 start_count = end_count
         else:
             for j, dict_data in enumerate(split_values):
@@ -234,52 +240,6 @@ class SecurityValueHolder(object):
             return df
 
 
-class RankedSecurityValueHolder(SecurityValueHolder):
-
-    def __init__(self, innerValue):
-        if isinstance(innerValue, SecurityValueHolder):
-            self._inner = copy.deepcopy(innerValue)
-        else:
-            # TODO: make the rank value holder workable for a symbol
-            raise ValueError("Currently only value holder input is allowed for rank holder.")
-        self._window = self._inner.window
-        self._returnSize = self._inner.valueSize
-        self._dependency = copy.deepcopy(self._inner._dependency)
-        self.updated = False
-        self.cached = pd.Series()
-
-    @property
-    def symbolList(self):
-        return self._inner.symbolList
-
-    @property
-    def value(self):
-        if self.updated:
-            return self.cached
-        else:
-            raw_values = self._inner.value
-            self.cached = raw_values.rank(ascending=False)
-            self.updated = True
-            return self.cached
-
-    def value_by_name(self, name):
-        if self.updated:
-            return self.cached[name]
-        else:
-            raw_values = self._inner.value
-            self.cached = raw_values.rank(ascending=False)
-            self.updated = True
-            return self.cached[name]
-
-    @property
-    def holders(self):
-        return self._inner.holders
-
-    def push(self, data):
-        self._inner.push(data)
-        self.updated = False
-
-
 class FilteredSecurityValueHolder(SecurityValueHolder):
     def __init__(self, computer, filtering):
         self._filter = copy.deepcopy(filtering)
@@ -321,6 +281,13 @@ class FilteredSecurityValueHolder(SecurityValueHolder):
             else:
                 return np.nan
 
+    def value_by_names(self, names):
+        if self.updated:
+            return self.cached[names]
+        else:
+            filter_value = self._filter.value_by_names(names)
+            return self._computer.value_by_names(names)[filter_value]
+
     def push(self, data):
         self._computer.push(data)
         self._filter.push(data)
@@ -384,6 +351,12 @@ class SecurityUnitoryValueHolder(SecurityValueHolder):
         else:
             return self._op(self._right.value_by_name(name))
 
+    def value_by_names(self, names):
+        if self.updated:
+            return self.cached[names]
+        else:
+            return self._op(self._right.value_by_names(names))
+
 
 class SecurityNegValueHolder(SecurityUnitoryValueHolder):
     def __init__(self, right):
@@ -452,6 +425,12 @@ class SecurityCombinedValueHolder(SecurityValueHolder):
         else:
             return self._op(self._left.value_by_name(name), self._right.value_by_name(name))
 
+    def value_by_names(self, names):
+        if self.updated:
+            return self.cached[names]
+        else:
+            return self._op(self._left.value_by_names(names), self._right.value_by_names(names))
+
 
 class SecurityAddedValueHolder(SecurityCombinedValueHolder):
     def __init__(self, left, right):
