@@ -7,7 +7,9 @@ Created on 2015-8-8
 
 from PyFin.Analysis.DataProviders import DataProvider
 from PyFin.Analysis.SecurityValueHolders import SecurityShiftedValueHolder
-from PyFin.Analysis.SecurityValueHolders import RankedSecurityValueHolder
+from PyFin.Analysis.CrossSectionValueHolders import CSRankedSecurityValueHolder
+from PyFin.Analysis.CrossSectionValueHolders import CSAverageSecurityValueHolder
+from PyFin.Analysis.CrossSectionValueHolders import CSAverageAdjustedSecurityValueHolder
 from PyFin.Analysis.SecurityValueHolders import SecurityLatestValueHolder
 from PyFin.Analysis.SecurityValueHolders import dependencyCalculator
 from PyFin.Analysis import TechnicalAnalysis
@@ -15,7 +17,9 @@ from PyFin.Analysis.transformer import transform
 
 __all__ = ['DataProvider',
            'SecurityShiftedValueHolder',
-           'RankedSecurityValueHolder',
+           'CSRankedSecurityValueHolder',
+           'CSAverageSecurityValueHolder',
+           'CSAverageAdjustedSecurityValueHolder',
            'SecurityLatestValueHolder',
            'dependencyCalculator',
            'TechnicalAnalysis',
