@@ -11,7 +11,6 @@ import pandas as pd
 from PyFin.Enums import Factors
 from PyFin.Analysis.SecurityValueHolders import SecuritiesValues
 from PyFin.Analysis.SecurityValueHolders import dependencyCalculator
-from PyFin.Analysis.SecurityValueHolders import RankedSecurityValueHolder
 from PyFin.Analysis.SecurityValueHolders import FilteredSecurityValueHolder
 from PyFin.Analysis.SecurityValueHolders import SecurityLatestValueHolder
 from PyFin.Analysis.TechnicalAnalysis import SecurityMovingAverage
@@ -38,20 +37,6 @@ class TestSecurityValueHolders(unittest.TestCase):
                                                                                             calculated[name]))
         self.checker = check_values
 
-    def testRankedSecurityValueHolder(self):
-        benchmark = SecurityLatestValueHolder(dependency='close')
-        rankHolder = RankedSecurityValueHolder(benchmark)
-
-        for i in range(len(self.datas['aapl']['close'])):
-            data = {'aapl': {Factors.CLOSE: self.datas['aapl'][Factors.CLOSE][i],
-                             Factors.OPEN: self.datas['aapl'][Factors.OPEN][i]},
-                    'ibm': {Factors.CLOSE: self.datas['ibm'][Factors.CLOSE][i],
-                            Factors.OPEN: self.datas['ibm'][Factors.OPEN][i]}}
-            benchmark.push(data)
-            rankHolder.push(data)
-            benchmarkValues = benchmark.value
-            np.testing.assert_array_almost_equal(benchmarkValues.rank(ascending=False), rankHolder.value)
-
     def testFilteredSecurityValueHolder(self):
         benchmark = SecurityLatestValueHolder(dependency='close') > 0
         filtered = FilteredSecurityValueHolder(benchmark, benchmark)
