@@ -32,10 +32,14 @@ def test():
     suite.addTests(tests)
     tests = unittest.TestLoader().loadTestsFromTestCase(Analysis.TestSecurityValueHolders)
     suite.addTests(tests)
+    tests = unittest.TestLoader().loadTestsFromTestCase(Analysis.TestCrossSectionValueHolder)
+    suite.addTests(tests)
     tests = unittest.TestLoader().loadTestsFromTestCase(Analysis.TestTransformer)
     suite.addTest(tests)
     tests = unittest.TestLoader().loadTestsFromTestCase(Analysis.TechnicalAnalysis.TestStatelessTechnicalAnalysis)
     suite.addTests(tests)
+    tests = unittest.TestLoader().loadTestsFromTestCase(Analysis.TechnicalAnalysis.TestStatelessTechnicalAnalysis)
+    suite.addTests(tests)
     tests = unittest.TestLoader().loadTestsFromTestCase(Analysis.TechnicalAnalysis.TestStatefulTechnicalAnalysis)
     suite.addTests(tests)
     tests = unittest.TestLoader().loadTestsFromTestCase(DateUtilities.TestCalendar)
@@ -54,6 +58,10 @@ def test():
     suite.addTests(tests)
     tests = unittest.TestLoader().loadTestsFromTestCase(PricingEngines.TestBlackFormula)
     suite.addTests(tests)
+    tests = unittest.TestLoader().loadTestsFromTestCase(PricingEngines.TestSabrFormula)
+    suite.addTests(tests)
+    tests = unittest.TestLoader().loadTestsFromTestCase(PricingEngines.TestSVIInterpolation)
+    suite.addTests(tests)
     tests = unittest.TestLoader().loadTestsFromTestCase(Math.Accumulators.TestAccumulatorImpl)
     suite.addTests(tests)
     tests = unittest.TestLoader().loadTestsFromTestCase(Math.Accumulators.TestAccumulatorsArithmetic)
